pub unsafe fn address_space_clone(src_root_va: u64) -> Option<u64>Expand description
clone an paging hierarchy (fuck me why can’t I spell this fucking word.) currently the kernel part is not deep copied i.e. all PML4 entries point to the original physical addresses of L3 tables. The user part is deep-copied without COW.
The actual virtual memory is also copied. unsafe: assume the pagetables are not ill-formed.
It both takes and returns VIRTUAL ADDRESSES